package
Version:
v0.0.0-...-31a7496
Opens a new window with list of versions in this module.
Published: Feb 19, 2023
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
MarkErrors logs error logs
func (g *Gin) Response(httpCode, errCode int, data interface{})
Response setting gin.JSON
type Response struct {
Code int `json:"code"`
Msg string `json:"msg"`
Data interface{} `json:"data"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.